Daskernetes
===========

|Build Status|

Native Kubernetes integration for Dask.

See documentation for more information:
`daskernetes.readthedocs.io <https://daskernetes.readthedocs.io/en/latest>`_

.. |Build Status| image:: https://circleci.com/gh/dask/daskernetes.svg?&style=shield
   :target: https://circleci.com/gh/dask/daskernetes.svg?&style=shield
